/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 *
 * Contributor(s):
 *
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package antapiusage;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Enumeration;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.tools.ant.util.*;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.net.URL;


/**
 * Simple servlet to invoke ant api to read a file when servelet is loaded.
 * In the web application deployment descriptor,
 * this servlet must be mapped to correspond to the link in the
 * "index.html" file.
 *
 * @author Preetam Deshpande <preetamd@gmail.com>
 */

public final class AntApiUsageServlet extends HttpServlet {


    /**
     * Respond to a GET request for the content produced by
     * this servlet.
     *
     * @param request The servlet request we are processing
     * @param response The servlet response we are producing
     *
     * @exception IOException if an input/output error occurs
     * @exception ServletException if a servlet error occurs
     */
    public void doGet(HttpServletRequest request,
                      HttpServletResponse response)
      throws IOException, ServletException {

	      System.out.println("Servlet processing do get..");

	response.setContentType("text/html");
	PrintWriter writer = response.getWriter();



	writer.println("<html>");
	writer.println("<head>");
	writer.println("<title>Ant API Usage Servlet Page</title>");
	writer.println("</head>");
	writer.println("<body bgcolor=white>");

	writer.println("<table border=\"0\">");
	writer.println("<tr>");
	writer.println("<td>");
	//writer.println("<img src=\"images/tomcat.gif\">");
	writer.println("</td>");
	writer.println("<td>");
	writer.println("<h1>Ant API Usage Servlet</h1>");
	writer.println("This is the output of a servlet that is part of");
	writer.println("the Ant API Usage application.  It displays the");
	writer.println("request headers from the request we are currently");
	writer.println("processing.");
	writer.println("</td>");
	writer.println("</tr>");
	writer.println("</table>");

	writer.println("<table border=\"0\" width=\"100%\">");
	Enumeration names = request.getHeaderNames();
	while (names.hasMoreElements()) {
	    String name = (String) names.nextElement();
	    writer.println("<tr>");
	    writer.println("  <th align=\"right\">" + name + ":</th>");
	    writer.println("  <td>" + request.getHeader(name) + "</td>");
	    writer.println("</tr>");
	}
	writer.println("</table>");

	String fileURL="No URL";
	String fileContent="No Content";
	boolean isFileRead = false;

	try{
		fileURL = getFileURL();
		fileContent = getFileContent();
		isFileRead = true;
	} catch (Exception e) {

		writer.println("Failed to read file default-web.xml using ANT FileUtils API");
		writer.println(e.toString());

	}

	if (isFileRead) {
		writer.println("<table border=\"0\">");
		writer.println("<tr>---------------------------------------------------------------------</tr>");
		writer.println("<tr>---------------------------------------------------------------------</tr>");
		writer.println("<tr>");
		writer.println("<td>");


		writer.println("URL " + fileURL);

		writer.println("</td>");
		writer.println("<td>");

		writer.println("Content " + fileContent);

		writer.println("</td>");
		writer.println("</tr>");
		writer.println("</table>");
	}

	writer.println("</body>");
	writer.println("</html>");

    }

    /**
     * Read the file URL of the default-web.xml file. Return the
     * file URL to the caller.
     * Using "FileUtilsObj.getFileURL(File)" ant api.
     *
     * @param String myurl is file url of the file default-web.xml
     *
     */
	public String getFileURL() throws Exception
	{
		File fd;
		FileUtils fu;
		FileReader rdr;
		URL myurl = null;

		fd = new File("default-web.xml");
		fu = FileUtils.getFileUtils();
		myurl = fu.getFileURL(fd);

		return String.valueOf(myurl);
	}


    /**
     * Read the defaul-web.xml in a String and return to caller.
     * Using "FileUtils.readFully(FileReader)" ant api.
     *
     * @param String fline is content of the file default-web.xml
     *
     */
	public String getFileContent() throws Exception
	{
			File fd;
			FileReader rdr;
			String fline = new String("Could not read file");

			fd = new File("default-web.xml");
			rdr = new FileReader(fd);
			fline = FileUtils.readFully(rdr);

			return fline;
	}

}

